Changelog
=========

.. currentmodule:: hancock

Release 1.1.2
-------------

*Update* - Using `getattr` instead of `__dict__` when invoking `requests` dynamically.

Release 1.1.1
-------------

*Update* - Added `DEBUG` variable to print out generate URL's on crud methods.

Release 1.1
-------------

*Release* - Fixed/Implemented the `validate` function. Removed `simplejson` ref for the built-in `json`.

Release 1.0
-------------

*Release* - Production release, included `PATCH` within the supported HTTP methods.

Release 0.1b0
-------------

*Update* - Beta release, added params to get, post, put, delete, request functions for timeout and verify_ssl


Release 0.1a0
-------------

Initial release
